@@ -240,7 +240,7 @@ class SettingsManager (GObject.Object):
         background_image = appearance_settings['background-image']
         if background_type is BackgroundType.image and background_image:
             css += "\n"
-            css += ".login-dialog,\n"
+            css += ".login-dialog { background: transparent; }\n"
             css += "#lockDialogGroup {\n"
             css += "  background-image: url('resource:///org/gnome/shell/theme/background');\n"
             css += "  background-size: cover;\n"
@@ -248,7 +248,8 @@ class SettingsManager (GObject.Object):
         elif background_type is BackgroundType.color:
             background_color = appearance_settings['background-color']
             css += "\n"
-            css += "#lockDialogGroup { background-color: "+ background_color + "; }\n"
+            css += ".login-dialog { background: transparent; }\n"
+            css += "#lockDialogGroup { background-color: " + background_color + "; }\n"
 
         ### Top Bar ###
         def select_elem(elem:str='') -> str:
